@@ -60,7 +60,7 @@ describe 'manila::db::mysql' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({ :fqdn => 'some.host.tld'}))
+        facts.merge!(OSDefaults.get_facts())
       end
       it_behaves_like 'manila::db::mysql'
     end
