@@ -3,10 +3,16 @@ require 'spec_helper'
 describe 'manila::image::glance' do
   shared_examples 'manila::glance' do
     context 'with default parameters' do
+      let :params do
+        {
+          :password => 'glancepass',
+        }
+      end
+
       it 'configures manila image glance' do
         is_expected.to contain_manila_config('glance/api_microversion').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('glance/insecure').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_manila_config('glance/auth_url').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_manila_config('glance/auth_url').with_value('http://127.0.0.1:5000')
         is_expected.to contain_manila_config('glance/auth_type').with_value('password')
         is_expected.to contain_manila_config('glance/cafile').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('glance/certfile').with_value('<SERVICE DEFAULT>')
@@ -16,9 +22,10 @@ describe 'manila::image::glance' do
         is_expected.to contain_manila_config('glance/project_name').with_value('services')
         is_expected.to contain_manila_config('glance/system_scope').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('glance/region_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_manila_config('glance/timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('glance/endpoint_type').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('glance/username').with_value('glance')
-        is_expected.to contain_manila_config('glance/password').with_value('<SERVICE DEFAULT>').with_secret(true)
+        is_expected.to contain_manila_config('glance/password').with_value('glancepass').with_secret(true)
       end
     end
 
@@ -31,9 +38,10 @@ describe 'manila::image::glance' do
           :auth_type        => 'v3password',
           :cafile           => '/etc/ssl/certs/ca.crt',
           :region_name      => 'RegionOne',
+          :timeout          => 60,
           :endpoint_type    => 'publicURL',
           :username         => 'glancev1',
-          :password         => '123123',
+          :password         => 'glancepass',
         }
       end
 
@@ -50,15 +58,17 @@ describe 'manila::image::glance' do
         is_expected.to contain_manila_config('glance/project_name').with_value('services')
         is_expected.to contain_manila_config('glance/system_scope').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('glance/region_name').with_value('RegionOne')
+        is_expected.to contain_manila_config('glance/timeout').with_value(60)
         is_expected.to contain_manila_config('glance/endpoint_type').with_value('publicURL')
         is_expected.to contain_manila_config('glance/username').with_value('glancev1')
-        is_expected.to contain_manila_config('glance/password').with_value('123123').with_secret(true)
+        is_expected.to contain_manila_config('glance/password').with_value('glancepass').with_secret(true)
        end
     end
 
     context 'when system_scope is set' do
       let :params do
         {
+          :password     => 'glancepass',
           :system_scope => 'all'
         }
       end
