@@ -36,21 +36,24 @@ describe 'manila' do
         is_expected.to contain_oslo__messaging__rabbit('manila_config').with(
           :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
           :amqp_durable_queues             => '<SERVICE DEFAULT>',
+          :amqp_auto_delete                => '<SERVICE DEFAULT>',
           :rabbit_ha_queues                => '<SERVICE DEFAULT>',
           :kombu_failover_strategy         => '<SERVICE DEFAULT>',
           :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
           :heartbeat_rate                  => '<SERVICE DEFAULT>',
-          :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
           :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
           :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
           :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
+          :rabbit_transient_queues_ttl     => '<SERVICE DEFAULT>',
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+          :use_queue_manager               => '<SERVICE DEFAULT>',
+          :rabbit_stream_fanout            => '<SERVICE DEFAULT>',
           :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_manila_config('DEFAULT/storage_availability_zone').with(
-          :value => 'nova'
+          :value => '<SERVICE DEFAULT>'
         )
         is_expected.to contain_manila_config('DEFAULT/api_paste_config').with(
           :value => '/etc/manila/api-paste.ini'
@@ -138,58 +141,45 @@ describe 'manila' do
       )}
     end
 
-    context 'with amqp_durable_queues disabled' do
-      let :params do
-        req_params.merge({
-          :amqp_durable_queues => false,
-        })
-      end
-
-      it { is_expected.to contain_oslo__messaging__rabbit('manila_config').with(
-        :amqp_durable_queues => false,
-      )}
-    end
-
-    context 'with amqp_durable_queues enabled' do
+    context 'with amqp options' do
       let :params do
         req_params.merge({
           :amqp_durable_queues => true,
+          :amqp_auto_delete    => false,
         })
       end
 
       it { is_expected.to contain_oslo__messaging__rabbit('manila_config').with(
         :amqp_durable_queues => true,
+        :amqp_auto_delete    => false,
       )}
     end
 
     context 'with SSL socket options set' do
       let :params do
         {
-          :use_ssl         => true,
-          :cert_file       => '/path/to/cert',
-          :ca_file         => '/path/to/ca',
-          :key_file        => '/path/to/key',
+          :use_ssl   => true,
+          :cert_file => '/path/to/cert',
+          :ca_file   => '/path/to/ca',
+          :key_file  => '/path/to/key',
         }
       end
 
-      it { is_expected.to contain_manila_config('DEFAULT/ssl_ca_file').with_value('/path/to/ca') }
-      it { is_expected.to contain_manila_config('DEFAULT/ssl_cert_file').with_value('/path/to/cert') }
-      it { is_expected.to contain_manila_config('DEFAULT/ssl_key_file').with_value('/path/to/key') }
+      it { is_expected.to contain_oslo__service__ssl('manila_config').with(
+        :ca_file   => '/path/to/ca',
+        :cert_file => '/path/to/cert',
+        :key_file  => '/path/to/key'
+      )}
     end
 
     context 'with SSL socket options set to false' do
       let :params do
         {
-          :use_ssl         => false,
-          :cert_file       => false,
-          :ca_file         => false,
-          :key_file        => false,
+          :use_ssl => false,
         }
       end
 
-      it { is_expected.to contain_manila_config('DEFAULT/ssl_ca_file').with_ensure('absent') }
-      it { is_expected.to contain_manila_config('DEFAULT/ssl_cert_file').with_ensure('absent') }
-      it { is_expected.to contain_manila_config('DEFAULT/ssl_key_file').with_ensure('absent') }
+      it { is_expected.to contain_oslo__service__ssl('manila_config') }
     end
 
     context 'with transport_url entries' do
