@@ -15,6 +15,7 @@ describe 'manila::keystone::auth' do
         :configure_user      => true,
         :configure_user_role => true,
         :configure_endpoint  => true,
+        :configure_service   => true,
         :service_name        => 'manila',
         :service_type        => 'share',
         :service_description => 'Manila Service',
@@ -23,7 +24,7 @@ describe 'manila::keystone::auth' do
         :password            => 'manila_password',
         :email               => 'manila@localhost',
         :tenant              => 'services',
-        :roles               => ['admin'],
+        :roles               => ['admin', 'service'],
         :system_scope        => 'all',
         :system_roles        => [],
         :public_url          => 'http://127.0.0.1:8786/v1/%(tenant_id)s',
@@ -35,17 +36,11 @@ describe 'manila::keystone::auth' do
         :configure_user      => false,
         :configure_user_role => false,
         :configure_endpoint  => true,
+        :configure_service   => true,
         :service_name        => 'manilav2',
         :service_type        => 'sharev2',
         :service_description => 'Manila Service v2',
         :region              => 'RegionOne',
-        :auth_name           => 'manilav2',
-        :password            => 'manila_password',
-        :email               => 'manilav2@localhost',
-        :tenant              => 'services',
-        :roles               => ['admin'],
-        :system_scope        => 'all',
-        :system_roles        => [],
         :public_url          => 'http://127.0.0.1:8786/v2',
         :internal_url        => 'http://127.0.0.1:8786/v2',
         :admin_url           => 'http://127.0.0.1:8786/v2',
@@ -58,12 +53,13 @@ describe 'manila::keystone::auth' do
           :auth_name              => 'alt_manila',
           :email                  => 'alt_manila@alt_localhost',
           :tenant                 => 'alt_service',
-          :roles                  => ['admin', 'service'],
+          :roles                  => ['admin'],
           :system_scope           => 'alt_all',
           :system_roles           => ['admin', 'member', 'reader'],
           :configure_endpoint     => false,
           :configure_user         => false,
           :configure_user_role    => false,
+          :configure_service      => false,
           :service_description    => 'Alternative Manila Service',
           :service_name           => 'alt_service',
           :service_type           => 'alt_share',
@@ -71,12 +67,8 @@ describe 'manila::keystone::auth' do
           :public_url             => 'https://10.10.10.10:80',
           :internal_url           => 'http://10.10.10.11:81',
           :admin_url              => 'http://10.10.10.12:81',
-          :password_v2            => 'manilav2_password',
-          :auth_name_v2           => 'alt_manilav2',
-          :email_v2               => 'alt_manilav2@alt_localhost',
           :configure_endpoint_v2  => false,
-          :configure_user_v2      => true,
-          :configure_user_role_v2 => true,
+          :configure_service_v2   => false,
           :service_description_v2 => 'Alternative Manila Service v2',
           :service_name_v2        => 'alt_servicev2',
           :service_type_v2        => 'alt_sharev2',
@@ -89,6 +81,7 @@ describe 'manila::keystone::auth' do
         :configure_user      => false,
         :configure_user_role => false,
         :configure_endpoint  => false,
+        :configure_service   => false,
         :service_name        => 'alt_service',
         :service_type        => 'alt_share',
         :service_description => 'Alternative Manila Service',
@@ -97,7 +90,7 @@ describe 'manila::keystone::auth' do
         :password            => 'manila_password',
         :email               => 'alt_manila@alt_localhost',
         :tenant              => 'alt_service',
-        :roles               => ['admin', 'service'],
+        :roles               => ['admin'],
         :system_scope        => 'alt_all',
         :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
@@ -106,20 +99,14 @@ describe 'manila::keystone::auth' do
       ) }
 
       it { is_expected.to contain_keystone__resource__service_identity('manilav2').with(
-        :configure_user      => true,
-        :configure_user_role => true,
+        :configure_user      => false,
+        :configure_user_role => false,
         :configure_endpoint  => false,
+        :configure_service   => false,
         :service_name        => 'alt_servicev2',
         :service_type        => 'alt_sharev2',
         :service_description => 'Alternative Manila Service v2',
         :region              => 'RegionTwo',
-        :auth_name           => 'alt_manilav2',
-        :password            => 'manilav2_password',
-        :email               => 'alt_manilav2@alt_localhost',
-        :tenant              => 'alt_service',
-        :roles               => ['admin', 'service'],
-        :system_scope        => 'alt_all',
-        :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.20:80',
         :internal_url        => 'http://10.10.10.21:81',
         :admin_url           => 'http://10.10.10.22:81',
