@@ -3,19 +3,26 @@ require 'spec_helper'
 describe 'manila::volume::cinder' do
   shared_examples 'manila::volume::cinder' do
     context 'with default parameters' do
+      let :params do
+        {
+          :password => 'cinderpass',
+        }
+      end
+
       it 'configures manila volume cinder' do
         is_expected.to contain_manila_config('cinder/insecure').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_manila_config('cinder/auth_url').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_manila_config('cinder/auth_url').with_value('http://127.0.0.1:5000')
         is_expected.to contain_manila_config('cinder/auth_type').with_value('password')
         is_expected.to contain_manila_config('cinder/cafile').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('cinder/region_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_manila_config('cinder/timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('cinder/endpoint_type').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('cinder/user_domain_name').with_value('Default')
         is_expected.to contain_manila_config('cinder/project_domain_name').with_value('Default')
         is_expected.to contain_manila_config('cinder/project_name').with_value('services')
         is_expected.to contain_manila_config('cinder/system_scope').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('cinder/username').with_value('cinder')
-        is_expected.to contain_manila_config('cinder/password').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_manila_config('cinder/password').with_value('cinderpass').with_secret(true)
         is_expected.to contain_manila_config('cinder/http_retries').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('cinder/cross_az_attach').with_value('<SERVICE DEFAULT>')
       end
@@ -29,9 +36,10 @@ describe 'manila::volume::cinder' do
           :auth_type       => 'v3password',
           :cafile          => '/etc/ssl/certs/ca.crt',
           :region_name     => 'RegionOne',
+          :timeout         => 60,
           :endpoint_type   => 'publicURL',
           :username        => 'cinderv1',
-          :password        => '123123',
+          :password        => 'cinderpass',
           :http_retries    => 3,
           :cross_az_attach => true,
         }
@@ -46,10 +54,11 @@ describe 'manila::volume::cinder' do
         is_expected.to contain_manila_config('cinder/project_domain_name').with_value('Default')
         is_expected.to contain_manila_config('cinder/project_name').with_value('services')
         is_expected.to contain_manila_config('cinder/region_name').with_value('RegionOne')
+        is_expected.to contain_manila_config('cinder/timeout').with_value(60)
         is_expected.to contain_manila_config('cinder/system_scope').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('cinder/endpoint_type').with_value('publicURL')
         is_expected.to contain_manila_config('cinder/username').with_value('cinderv1')
-        is_expected.to contain_manila_config('cinder/password').with_value('123123').with_secret(true)
+        is_expected.to contain_manila_config('cinder/password').with_value('cinderpass').with_secret(true)
         is_expected.to contain_manila_config('cinder/http_retries').with_value(3)
         is_expected.to contain_manila_config('cinder/cross_az_attach').with_value('true')
        end
@@ -58,6 +67,7 @@ describe 'manila::volume::cinder' do
     context 'when system_scope is set' do
       let :params do
         {
+          :password     => 'cinderpass',
           :system_scope => 'all'
         }
       end
