@@ -16,15 +16,19 @@ describe 'manila::backend::dellemc_unity' do
 
   let :default_params do
     {
-      :emc_share_backend              => 'unity',
-      :unity_share_data_pools         => '<SERVICE DEFAULT>',
-      :unity_ethernet_ports           => '<SERVICE DEFAULT>',
-      :unity_share_server             => '<SERVICE DEFAULT>',
-      :report_default_filter_function => '<SERVICE DEFAULT>',
-      :network_plugin_ipv6_enabled    => true,
-      :emc_ssl_cert_verify            => '<SERVICE DEFAULT>',
-      :emc_ssl_cert_path              => '<SERVICE DEFAULT>',
-      :backend_availability_zone      => '<SERVICE DEFAULT>',
+      :emc_share_backend                       => 'unity',
+      :unity_share_data_pools                  => '<SERVICE DEFAULT>',
+      :unity_ethernet_ports                    => '<SERVICE DEFAULT>',
+      :unity_share_server                      => '<SERVICE DEFAULT>',
+      :report_default_filter_function          => '<SERVICE DEFAULT>',
+      :network_plugin_ipv6_enabled             => true,
+      :emc_ssl_cert_verify                     => '<SERVICE DEFAULT>',
+      :emc_ssl_cert_path                       => '<SERVICE DEFAULT>',
+      :backend_availability_zone               => '<SERVICE DEFAULT>',
+      :reserved_share_percentage               => '<SERVICE DEFAULT>',
+      :reserved_share_from_snapshot_percentage => '<SERVICE DEFAULT>',
+      :reserved_share_extend_percentage        => '<SERVICE DEFAULT>',
+      :max_over_subscription_ratio             => '<SERVICE DEFAULT>',
     }
   end
 
@@ -44,6 +48,14 @@ describe 'manila::backend::dellemc_unity' do
     it 'marks emc_nas_password as secret' do
       is_expected.to contain_manila_config("dellemc_unity/emc_nas_password").with_secret( true )
     end
+
+    it 'installs storops library' do
+      is_expected.to contain_package('storops').with(
+        :ensure   => 'installed',
+        :provider => 'pip',
+        :tag      => 'manila-support-package',
+      )
+    end
   end
 
   shared_examples 'manila::backend::dellemc_unity' do
@@ -58,14 +70,18 @@ describe 'manila::backend::dellemc_unity' do
     context 'with provided parameters' do
       let :params do
         required_params.merge({
-          :unity_share_data_pools         => '*',
-          :unity_ethernet_ports           => 'eth1',
-          :unity_share_server             => '192.168.0.1',
-          :report_default_filter_function => false,
-          :network_plugin_ipv6_enabled    => true,
-          :emc_ssl_cert_verify            => true,
-          :emc_ssl_cert_path              => '/etc/ssl/certs/',
-          :backend_availability_zone      => 'my_zone',
+          :unity_share_data_pools                  => '*',
+          :unity_ethernet_ports                    => 'eth1',
+          :unity_share_server                      => '192.168.0.1',
+          :report_default_filter_function          => false,
+          :network_plugin_ipv6_enabled             => true,
+          :emc_ssl_cert_verify                     => true,
+          :emc_ssl_cert_path                       => '/etc/ssl/certs/',
+          :backend_availability_zone               => 'my_zone',
+          :reserved_share_percentage               => 10.0,
+          :reserved_share_from_snapshot_percentage => 10.1,
+          :reserved_share_extend_percentage        => 10.2,
+          :max_over_subscription_ratio             => 1.5,
         })
       end
 
@@ -81,6 +97,16 @@ describe 'manila::backend::dellemc_unity' do
 
      it { is_expected.to raise_error(Puppet::Error) }
     end
+
+    context 'with storops library unmanaged' do
+      let :params do
+        required_params.merge({
+          :manage_storops => false
+        })
+      end
+
+      it { is_expected.to_not contain_package('storops') }
+    end
   end
 
   on_supported_os({
